#
# spec file for package imagej
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define SrcVersion 151u

Name:           imagej
Version:        1.51u
Release:        lp152.3.5
Summary:        A Java image processing program
License:        SUSE-Public-Domain
Group:          Productivity/Graphics/Convertors
Url:            http://rsbweb.nih.gov/ij/
Source:         http://rsbweb.nih.gov/ij/download/src/ij%{SrcVersion}-src.zip
Source1:        %{name}.in
Source2:        %{name}.desktop
BuildRequires:  ImageMagick
BuildRequires:  ant
BuildRequires:  java-devel
BuildRequires:  unzip
BuildRequires:  update-desktop-files
Requires:       java >= 1.6.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
ImageJ is a multithreaded image processing program inspired by NIH
Image for the Macintosh, running either as an applet or as a
standalone program.

It can read many image formats including TIFF, GIF, JPEG, BMP, DICOM,
FITS and "raw", and display, edit, anazlye, process and print
8/16/32-bit images. It supports "stacks", a series of images that
share a single window. It can calculate area and pixel value
statistics of user-defined selections, measure distances and angles,
create density histograms and line profile plots, supports standard
image processing functions such as contrast manipulation, sharpening,
smoothing, edge detection and median filtering. It does geometric
transformations such as scaling, rotation and flips. Zoom in/out up
to 32:1/1:32. Spatial calibration is available to provide real-world
dimensional measurements in units such as millimeters. Density or
gray scale calibration is also available.

ImageJ can be extended via Java plugins, and has a built-in editor and
compiler.

%prep
%setup -n source

%build
%ant build

%install
install -d -m 755 %{buildroot}%{_datadir}/%{name}
install -m 755 ij.jar %{buildroot}%{_datadir}/%{name}/%{name}.jar

# startscript
cat > %{name} << 'EOF'
#!/bin/sh
#
# imagej startscript
#
# Source functions library
echo Starting %{name} version %{version} ...
echo with options : ${@}

java -jar %{_datadir}/%{name}/imagej.jar ${@}

EOF

install -d -m 755 %{buildroot}%{_bindir}
install -m 755 %{name} %{buildroot}%{_bindir}/

# Icon
convert -strip build/microscope.gif build/%{name}.png
install -Dm 644 build/%{name}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

# Desktop menu entry
install -d -m 755 %{buildroot}%{_datadir}/applications
install -m 644 %{SOURCE2} %{buildroot}%{_datadir}/applications/%{name}.desktop
%suse_update_desktop_file %{name}

%files
%defattr(-,root,root)
%doc release-notes.html
%{_bindir}/*
%{_datadir}/%{name}
%{_datadir}/%{name}/*.jar
#%{_datadir}/%{name}/lib/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%changelog
* Sun Feb 18 2018 jengelh@inai.de
- Wrap and compact description.
* Thu Feb 15 2018 robby.engelmann@igfs-ev.de
- Update to 1.51u
  * possible to run on Java 9
  * Java plugins can now iterate over the points contained in a selection
  * added support for diamond symbols to the Plot class
  * many more bugfixes and usability improvements
* Tue Mar  8 2016 bwiedemann@suse.com
- drop build time from png file to fix build-compare
* Tue Apr  9 2013 lumnis@opensuse.org
- Update to version 1.47n
  * see included release-notes.html
* Sun Dec 23 2012 dmitry_r@opensuse.org
- Remove _service for downloading files
- Use ImageMagick for icon converting
- Update to version 1.47g
  * see included release-notes.html
* Fri Sep 14 2012 lumnis@opensuse.org
- startup script fix (in spec file)
* Thu Sep 13 2012 dmitry_r@opensuse.org
- Various spec file cleanups
* Wed Sep 12 2012 lumnis@opensuse.org
- vers update 1.47c
  * Added a "Source" (display source code of selected command) button to Plugins>Utilities>Find Commands.
  * Dorai Iyer added a "Bar" option to the arrow tool.
  * Bill Mohler modified the ROI Manager to use a JList instead of a List, which makes loading and sorting the large (>10,000) ROI sets faster.
  * Added an "Append results" checkbox to the ROI Manager's "Multi Measure" command.
  * When opening images, the transfer rate in MB/sec is displayed in the status bar.
  * Thanks to Sébastien Tosi, opening TIFF files using File>Import>URL is faster and requires less memory.
  * Thanks to Jan Eglinger, fixed a bug that caused incorrect recording of commands implemented in JavaScript when the recorder was in "JavaScript" mode.
  * Thanks to Sébastien Tosi, fixed a bug that caused File>Import>URL to not correctly read TIFF files larger than 2GB.
  * Fixed a bug in the Analyze>Tools>Synchronize Windows command that caused it to not work as expected when changing the channel of composite color images.
  * Thanks to Christoph Deil, fixed a bug in Plugins>Utilities>Find Commands that caused esc and ctrl-w key presses to not close the window after "Show full information" was enabled.
  * Thanks to Christoph Deil, fixed bugs in the "Save changes?" dialog that caused it to not work as expected after the focus was changed (by tabbing) to the "Don't Save" or "Cancel" buttons.
  1.47b 12 August 2012
  * Added the Image>Stacks>Statistics command.
  * Thanks to Michael Schmid, the built in brush, pencil and overlay brush tools draw using the background color when alt key is down, are constrained to draw horizontally when shift is down, are resized when shift&control are down (shift&cmd on Macs), and "pick up" the foreground color when control is down (cmd on Macs).
  * Added a "16 bit range" choice to the Edit>Options>Appearance dialog box. This is the same as the "Unsigned 16 bit range" choice in the Brightness/Contast Adjuster's "Set" dialog.
  * Thanks to Olivio Donati, File>Import>Image Sequence opens any associated ROIs that are in a file named RoiSet.zip.
  * Thanks to David Knecht, added a "sum" option to Image>Transform>Bin.
  * The getHistogram() macro function no longer limits the number of bins to 256 with 8-bit and RGB images.
  * Added the IJ.createHyperStack(title,width,height,channels,slices,frames,bitdepth) method, where 'bitdepth' is 8, 16, 24 (rgb), or 32 (float).
  * Thanks to Qingzong Tseng, fixed a bug that caused overlays to be lost when converting composite stacks to RGB.
  * Thanks to Jan Eglinger, fixed a bug that caused images created by the particle analyzer's "Show:" option to not use the calibration of the original image.
  * Thanks to Guenter Giese, fixed bugs that caused the "Unsigned 16 bit range" choice in the Brightness/Contast Adjuster's "Set" dialog to not work as expected with multi-channel images.
  * Thanks to Barry DeZonia, fixed a bug that caused the command recorder to not work with Image>Stacks>3D Project when processing 16 and 32 bit images.
  * Thanks to William Edwards, fixed a bug that sometimes caused the median of 32-bit float images to be calculated incorrectly.
  * Thanks to Michael Cammer, worked around a bug that could cause commands in the Image>Type submenu to not work as expected in non-batch-mode macros.
  1.47a 17 July 2012
  * Thanks to Thomas Boudier, added five new 3D filters (Median, Mean, Minimum, Maximum and Variance) to the Process>Filters submenu.
  * Added the "Restore Startup Tools" command to the toolbar's >> menu.
  * Thanks to Tiago Ferreira, built-in and plugin tools can be added to toolsets and the startup macros (example).
  * Michael Schmid modified the Overlay Brush tool for constrained motion (vertical or horizontal) with shift and resizing with ctrl-shift (cmd-shift on Macs).
  * Thomas Tongue added support for the CDELT and CTYPE headers to the FITS Reader.
  * Added the getinfo("selection.color") and getValue("selection.width") macro functions.
  * Thanks to Simon Roussel, fixed a bug that could cause overlays to not be displayed on virtual stacks.
  * Fixed a bug that caused the brush and pencil tools to activate overlay selections.
  * Michael Schmid fixed a bug that sometimes caused Preview to not work correctly with commands in the Process>Filters submenu.
  * Fixed a 1.46 regression that caused the ROI Manager to generate incorrect ROI labels when the Associate 'Show All" ROIs with Slices" option was not enabled.
  * Thanks to Stephan Semmler, fixed a regression that caused the ImagePlus.getNDimensions() method to sometimes return the wrong value.
  * Thanks to Glen MacDonald, fixed a 1.46 regression that caused the setOption("Show All",boolean) macro function to not work.
* Fri Jun  1 2012 lumnis@opensuse.org
- version update 1.46o 18 May 2012
  * Set the stroke width to 0 in the Edit>Selection>Properties,
    Image>Overlay>Overlay Options and ROI ManagerProperties dialogs
    to have selections drawn using a width of one pixel
    regardless of the image magnification.
  * Fixed a bug that could cause selections being moved to not be
    displayed correctly when the "Use ROI names as labels" option in
    the ROI Manager was enabled.
  * Fixed a bug that caused Analyze>Plot Profile to fail with line
    selections with widths less than 1.0.
  * Thanks to Franklin Shaffer, fixed a bug that sometimes a caused a
    stack overflow error when importing large image sequences.
  * Thanks to Tiago Ferreira, fixed a 1.46n regression that caused overlay
    items to be removed when toggling the ROI Manager "Show All" checkbox.
- changes in 1.46n 11 May 2012
  * In "Show All" mode, the ROI Manager now uses an overlay to
    display the selections.
  * Added the More>>Labels... command to the ROI Manager, as a
    shortcut to Image>Overlay>Labels.
  * Add a "Show plot" checkbox to the Analyze>Calibrate dialog box.
  * File>Save As>XY Coordinates now correctly saves subpixel resolution
    selections, and it works with more kinds of selections.
  * Tiago Ferreira added a list of valid factors to the
    Image>Stacks>Tools>GroupedZProjector dialog.
  * Made the IJ.runPlugIn(String,String,String) method public.
  * Added the IJ.getFullVersion() method.
  * Thanks to Burri Olivier, fixed a bug that caused Image>Adjust>Threshold,
    when the "Stack histogram" option was enabled, to use the histogram of
    all channels instead of only the current channel.
  * Tiago Ferreira fixed a bug that caused stacks binned with
    Image>Stacks>Tools>GroupedZProjector to loose spatial calibration.
  * Thanks to Burri Olivier, fixed a bug that caused incorrect auto stack
    thresholds when "Limit to threshold was enabled in Analyze>Set Measurements.
  * Thanks to Thomas Boudier and Michael Schmid, fixed a bug that caused
    the Analyze>Summarize command to not work correctly on reopened results tables.
  * Thanks to Jim Passmore, fixed a bug that caused NonBlockingDialogs to
    not handle the yes/no/cancel option.
  * Thanks to Norbert Vischer, fixed a bug that caused Image>Show Info to
    incorrectly display the selection location when the image origin was not (0,0).
* Wed May  2 2012 lumnis@opensuse.org
- vers update 1.46m
  * ROIs in an overlay can be activated by alt-clicking, control-clicking or long-pressing.
  * Thanks to Gabriel Landini, the Brush and Pencil tools installed from the toolbar's >> menu can be resized by shift-dragging.
  * The icons for drawing tools installed from the toolbar's >> menu reflect the foreground color and are updated when the foreground color changes.
  * Commands in the Edit>Selection submenu that modify the selection now support Undo and Redo and transfer color and line width properties.
  * Fiji saves and loads custom tool configurations.
  * Thanks to Ved Sharma, removed the restriction in Image>Stacks>Tools>Insert that the destination must be a stack.
  * Thanks to Richie Mort, fixed a bug that could cause the contents of multiple custom results tables created by plugins to be invalid.
* Thu Mar 29 2012 lumnis@opensuse.org
- vers update 1.46j
* Wed Feb 22 2012 lumnis@opensuse.org
- vers update 1.45g
* Mon Feb 13 2012 lumnis@opensuse.org
- vers update 1.45f
- ant build target set to : build
* Mon Sep  5 2011 lumnis@opensuse.org
- vers update 1.45m
* Fri Jul 22 2011 lumnis@opensuse.org
- vers update 1.45l
* Fri Jun 10 2011 lumnis@opensuse.org
- vers update 1.45i
* Thu May  5 2011 lumnis@opensuse.org
- update vers 1.45
* Thu Jan 14 2010 lumnis@opensuse.org
- copy from home:martin_ginkel
- updated version 1.44
- package cleanup e.g. changelog
